@@ -4,14 +4,14 @@ stores spectral data in the Hierarchical Data Format (HDF5).
 
 glue files are HDF5 files with the spectral data stored in a dataset names
 'spectrum' and any parameters stored in the dataset attributes.  At minimum
-the parameter dictionary must contain a ndim key with the dimentionality of
-the data and a dictionry for each axis numbered (0,1,2...) with the following
+the parameter dictionary must contain a ndim key with the dimensionality of
+the data and a dictionary for each axis numbered (0,1,2...) with the following
 keys:
 
 ========    =====================================================
 Key         Description
 ========    =====================================================
-car         Carrier freqiency in Hz
+car         Carrier frequency in Hz
 complex     True for complex data, False for magnitude
 encoding    type of encoding, 'states', 'tppi', 'direct', etc
 freq        True for frequency domain data, False otherwise
@@ -35,7 +35,7 @@ def make_uc(dic, data, dim=-1):
     make a unit conversion object
     """
     if dim == -1:
-        dim = data.ndim - 1  # last dimention
+        dim = data.ndim - 1  # last dimension
 
     size = dic[dim]["size"]
     cplex = dic[dim]["complex"]
@@ -79,7 +79,7 @@ def read(filename, dataset="spectrum"):
 
 def read_lowmem(filename, dataset="spectrum"):
     """
-    Read a glue file using mimimal memory usage
+    Read a glue file using minimal memory usage
     """
     f = h5py.File(filename, 'r')
     dic = get_dic(f, dataset)
@@ -101,7 +101,6 @@ def write(filename, dic, data, dataset="spectrum", overwrite=False):
     put_dic(f, dic, dataset)
 
     f.close()
-    return
 
 
 # data wrapping functions
@@ -156,7 +155,7 @@ def put_dic(f, dic, dataset="spectrum"):
     for key, value in dic.items():
 
         # axis dictionaries
-        if type(key) == int and type(value) == dict:
+        if type(key) is int and type(value) is dict:
             axis = key
             for axiskey, axisvalue in value.items():
                 fullkey = str(axis) + "_" + axiskey
@@ -165,7 +164,6 @@ def put_dic(f, dic, dataset="spectrum"):
         # simple value
         else:
             dset.attrs[key] = value
-    return
 
 
 # glue_* objects
@@ -206,7 +204,7 @@ class glue_2d(fileiobase.data_nd):
         """
         Return ndarray of selected values
 
-        (sY,sX) is a well formated tuple of slices
+        (sY,sX) is a well formatted tuple of slices
         """
         sY, sY = slices
         return self.Dataset[sY, sX]
@@ -250,7 +248,7 @@ class glue_3d(fileiobase.data_nd):
         """
         Return ndarray of selected values
 
-        (sZ, sY, sX) is a well formated tuple of slices
+        (sZ, sY, sX) is a well formatted tuple of slices
         """
         sZ, sY, sX = slices
         return self.Dataset[sZ, sY, sX]
